========================================================================
``psyclone.domain.nemo.transformations.nemo_outerarrayrange2loop_trans``
========================================================================

.. automodule:: psyclone.domain.nemo.transformations.nemo_outerarrayrange2loop_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.nemo.transformations.nemo_outerarrayrange2loop_trans


Classes
=======

- :py:class:`NemoOuterArrayRange2LoopTrans`:
  Provides a transformation from the outermost PSyIR ArrayReference


.. autoclass:: NemoOuterArrayRange2LoopTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: NemoOuterArrayRange2LoopTrans
      :parts: 1
